@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
     See the file "LICENSE" for the full license governing this code. 
-    Copyright 2011 Ken Farmer
+    Copyright 2011,2012,2013 Ken Farmer
 """
 
 import sys
@@ -16,8 +16,8 @@ from sqlalchemy import create_engine, MetaData, exc
 from sqlalchemy import Table, Column, Integer, String
 from sqlalchemy import ForeignKeyConstraint, UniqueConstraint, CheckConstraint
 
-sys.path.append('../')
-import simplesql  
+sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
+import gristle.simplesql   as simplesql
 
 #---------------------------------------------------------
 # test classes included here:
@@ -28,12 +28,13 @@ import simplesql
 #   Test_reports
 #---------------------------------------------------------
 
-def suite():
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestSurrogateKeyTable))
-    suite.addTest(unittest.makeSuite(TestNaturalKeyTable))
-    suite.addTest(unittest.makeSuite(TestSurrogateKeyCheckConstraintTable))
-    return suite
+#def suite():
+#    suite = unittest.TestSuite()
+#    suite.addTest(unittest.makeSuite(TestSurrogateKeyTable))
+#    suite.addTest(unittest.makeSuite(TestNaturalKeyTable))
+#    suite.addTest(unittest.makeSuite(TestSurrogateKeyCheckConstraintTable))
+#    unittest.TextTestRunner(verbosity=2).run(suite)
+#    return suite
 
 
 class TestSurrogateKeyTable(unittest.TestCase):
@@ -319,9 +320,9 @@ class AnimalTools(simplesql.TableTools):
 
 
 
-if __name__ == "__main__":
-
-    runner = unittest.TextTestRunner(verbosity=2)
-    runner.run(suite())
+#if __name__ == "__main__":
+    #runner = unittest.TextTestRunner(verbosity=2)
+    #runner.run(suite())
+#   unittest.main(suite())
  
 
